#!/bin/bash -e

. ./fusion-sys.cfg

# Was previous step completed?
if [ ! -f installed.basedir ]; then
    echo "Base directory structure was not completed" >&2
    exit 1
fi

# Is SourceGuardian already installed?
if [ -f installed.sourceguardian ]; then
    echo "SourceGuardian already installed - skipping..."
    exit 0
fi

# Get PHP version
phpver=$(php -v | head -n 1 | cut -d ' ' -f 2 | cut -d . -f 1,2)

ixedfile="ixed.$phpver.lin"
entry="extension=$ixedfile"

if [ "$arch" = "x86_64" ]; then
    zipfile="sg/ixed4.lin.x86-64.zip"
else
    zipfile="sg/ixed4.lin.x86-32.zip"
fi

# Extract SourceGuardian extension to the proper directory
unzip -o "$zipfile" "$ixedfile" -d "$php_extension_dir"

if [ -f "$php_extension_dir/$ixedfile" ]; then
    echo "Sourceguardian extension found for PHP version $phpver"
else
    echo "No valid Sourceguardian extension found for PHP version $phpver"
    exit 1
fi

if grep -q "$entry" "$phpini" "$phpconfd"/*; then
    echo "Sourceguardian extension already in php.ini"
else
    # If we are on Ubuntu/Debian, we need to add the sourceguardian extension to the CLI ini for the poll_subsys
    if [ "$dist" == "ubuntu14" ] || [ "$dist" == "ubuntu16" ] || [ "$dist" == "debian7" ] || [ "$dist" == "debian8" ] || [ "$dist" == "debian9" ]; then
        echo "Configuring php.ini for Sourceguardian..."
        echo "; Added by Nagios" >> $phpini
        echo "$entry" >> $phpini
        echo "; Added by Nagios" >> $php_cli_ini
        echo "$entry" >> $php_cli_ini
    fi

    echo "Adding Sourceguardian extension to php.ini"
    echo "$entry" > "$phpconfd"/sourceguardian.ini
fi

service "$httpd" restart

echo "SourceGuardian installed OK"
touch installed.sourceguardian